@@ -1,3 +1,5 @@
+from ast import literal_eval
+
 import climetlab as cml
 from climetlab.core.caching import (
     cache_directory,
@@ -88,6 +90,18 @@ def cache():
         raise NotImplementedError()
 
 
+@app.route("/api/cache/delete", methods=["DELETE"])
+def cache_delete():
+    # decode request string
+    files_to_delete = request.data.decode("UTF-8")
+    # convert a string representation of list to list datatype.
+    files_to_delete = literal_eval(files_to_delete)
+    # delete files via Climetlab.
+    for f in files_to_delete:
+        print(f"Deleting file - {f}\n")
+    return {"data": "Files deleted."}
+
+
 @app.route("/api/cache/meta", methods=["GET"])
 def cache_meta():
     matcher = Matcher(dict(request.args))
@@ -96,8 +110,8 @@ def cache_meta():
     if not matcher.undefined:
         message = matcher.message
     return {
-        "count": count,
-        "size": size,
+        "count": str(count),
+        "size": str(size),
         "message": message,
     }
 
@@ -107,9 +121,9 @@ def settings():
     if request.method == "GET":
         res = cml.settings.dump()
         res = list(res)
-        for k in res:
-            print(k)
-        return {"settings": res}
+        res = [{r[0]: str(r[1])} for r in res]
+        print(res)
+        return {"data": res}
 
 
 def run_server():
